/*
 *
 * Copyright c 2005-2009
 * Licensed under the Apache License, Version 2.0 (the "License")
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 */
/********************************************************************************
 * @author chaostone
 * 
 * MODIFICATION DESCRIPTION
 * 
 * Name                 Date                Description 
 * ============         ============        ============
 * chaostone             2006-8-28            Created
 *  
 ********************************************************************************/
package org.beangle.security.monitor;

import javax.servlet.http.HttpSession;

import org.beangle.security.auth.Authentication;
import org.beangle.security.auth.AuthenticationException;
import org.beangle.security.auth.AuthenticationManager;
import org.beangle.security.auth.provider.rememberme.RememberMeService;
import org.beangle.security.monitor.service.AuthorityManager;
import org.beangle.security.monitor.service.HttpSessionListener;

/**
 * 用户在线服务提供类
 * 
 * @author chaostone
 * 
 */
public interface SecurityMonitor {
	/**
	 * 认证
	 * 
	 * @param auth
	 * @param httpRequest
	 * @return
	 * @throws AuthenticationException
	 */
	public Authentication authenticate(Authentication auth) throws AuthenticationException;

	/**
	 * 退出
	 * 
	 * @see HttpSessionListener
	 * @param sessionId
	 */
	public void logout(HttpSession session);

	/**
	 * enableRememberMe
	 * 
	 * @return
	 */
	public boolean isEnableRememberMe();

	/**
	 * @see RememberMeService
	 * @return
	 */
	public RememberMeService getRememberMeService();

	// --------------------------authrization-------------------
	/**
	 * 是否经过授权
	 * 
	 * @param user
	 * @param resourceName
	 * @return
	 */
	public boolean isAuthorized(Long userId, String resourceName);

	/**
	 * 是否忽略判断
	 * 
	 * @param resourceName
	 * @return
	 */
	public boolean isPublicResource(String resourceName);

	/**
	 * 认证服务
	 * @return
	 */
	public AuthenticationManager getAuthenticationManager();

	/**
	 * 授权服务
	 * @return
	 */
	public AuthorityManager getAuthorityManager();

}
