package org.beangle.security.monitor.access.log;

import javax.servlet.http.HttpServletRequest;

import org.beangle.security.monitor.access.AccessLog;
import org.beangle.security.monitor.access.config.ConfigLoader;

public class AccessLogFactory {

	public static AccessLog getLog(HttpServletRequest request) {
		DefaultAccessLog log = null;
		if (UserAccessLog.class.getName().equals(
				ConfigLoader.getInstance().getConfig().getAccessLogClass())) {
			UserAccessLog userAccessLog = new UserAccessLog();
			userAccessLog.setUser(request.getSession().getAttribute(
					ConfigLoader.getInstance().getConfig().getUserKey()));
			log = userAccessLog;
		} else {
			log = new DefaultAccessLog();
		}
		log.setUri(getRequestURI(request));
		log.setParams(request.getQueryString());
		return log;
	}
	
	public static String getRequestURI(HttpServletRequest request) {
		String actionName = request.getServletPath();
		if (actionName.startsWith("/")) {
			actionName = actionName.substring(1);
		}
		return actionName;
	}
	
	/**
	 * 获取远程访问的客户IP
	 * 
	 * @param request
	 * @return
	 */
	public static String getIpAddr(HttpServletRequest request) {
		String ip = request.getHeader("x-forwarded-for");
		if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
			ip = request.getHeader("Proxy-Client-IP");
		}
		if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
			ip = request.getHeader("WL-Proxy-Client-IP");
		}
		if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
			ip = request.getRemoteAddr();
		}
		return ip;
	}
}
