package org.beangle.security.monitor.service;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

import org.beangle.security.auth.Authentication;
import org.beangle.security.auth.ServletRequestAware;
import org.beangle.security.auth.provider.AbstractAuthenticationListener;
import org.beangle.security.auth.session.CategoryProfile;
import org.beangle.security.auth.session.OnlineActivity;
import org.beangle.security.auth.ui.UserDetails;

public class HttpSessionListener extends AbstractAuthenticationListener {

	public void afterAuthenticate(Authentication auth) {
		if (auth instanceof ServletRequestAware) {
			HttpServletRequest request = ((ServletRequestAware) auth).getRequest();
			if (null == request) {
				return;
			}
			HttpSession session = request.getSession();
			CategoryProfile profile = authenticationManager.getSessionController()
					.getProfileProvider().getCategoryProfile(
							((UserDetails) auth.getDetails()).getCategory());
			session.setMaxInactiveInterval(profile.getInactiveInterval() * 60);
			((ServletRequestAware) auth).setRequest(null);
			UserDetails details = (UserDetails) auth.getDetails();
			if (null == details) {
				return;
			}
			session.setAttribute(Authentication.USERID, details.getUserid());
			session.setAttribute(Authentication.LOGINNAME, auth.getPrincipal());
			session.setAttribute(Authentication.FULLNAME, details.getFullname());
			session.setAttribute(Authentication.USER_CATEGORYID, details.getCategory().getId());
			logger.debug(
					"added session attributes USERID,LOGINNAME,USERNAME,USER_CATEGORYID for {}",
					auth.getPrincipal());
		}
	}

	public void afterRemove(OnlineActivity activity) {
		HttpSession session = HttpSessionHolder.getSession();
		if (null == session) {
			return;
		}
		session.removeAttribute(Authentication.USERID);
		session.removeAttribute(Authentication.LOGINNAME);
		session.removeAttribute(Authentication.FULLNAME);
		session.removeAttribute(Authentication.USER_CATEGORYID);
		logger.debug("clean session attribute USERID,LOGINNAME,USERNAME,USER_CATEGORYID");
		HttpSessionHolder.remove();
	}

}
